import pytest
from trail4_second_assignment import lengthoflist


@pytest.mark.parametrize(
    "x,expected", [([1, 2, 3], 3), (["Pooja", "Rihaan"], 2), ([], 0)]
)
def test_length(x, expected):
    assert lengthoflist(x) == expected



def dividenum(x, y):
    divide = x / y
    print("Hello Poojaa")
    return divide


def multiplynum(x, y):
    multiply = x * y
    return multiply


def addnumber(x, y):
    add = x + y
    return add


def subnum(x, y):
    sub = x - y
    return sub



import pytest
from trial4 import dividenum, multiplynum, addnumber, subnum


@pytest.mark.parametrize(
    "x,y,result",
    [(40, 10, 4), (49, 7, 7), pytest.param(90, 10, 9, marks=pytest.mark.xfail)],
)
def test_divide(x, y, result):
    assert dividenum(x, y) == result


@pytest.mark.parametrize(
    "x,y,expected",
    [(20, 10, 200), (5, 8, 40), pytest.param(90, 10, 110, marks=pytest.mark.xfail)],
)
def test_multiply(x, y, expected):
    assert multiplynum(x, y) == expected


@pytest.mark.parametrize(
    "x,y,expected",
    [(5, 4, 9), (3, 10, 13), pytest.param(90, 10, 110, marks=pytest.mark.xfail)],
)
def test_add(x, y, expected):
    assert addnumber(x, y) == expected


@pytest.mark.parametrize(
    "x,y,result",
    [(10, 8, 2), (100, 50, 50), pytest.param(90, 10, 110, marks=pytest.mark.xfail)],
)
def test_substract(x, y, result):
    assert subnum(x, y) == result
